@@ -19,6 +19,8 @@ from .message import Message
 from .unpack import unpack_variants as unpack
 from .validators import assert_bus_name_valid, assert_object_path_valid
 
+_LOGGER = logging.getLogger(__name__)
+
 
 @dataclass
 class SignalHandler:
@@ -119,11 +121,11 @@ class BaseProxyInterface:
             return
 
         match = [s for s in self.introspection.signals if s.name == msg.member]
-        if not len(match):
+        if not match:
             return
         intr_signal = match[0]
         if intr_signal.signature != msg.signature:
-            logging.warning(
+            _LOGGER.warning(
                 f'got signal "{self.introspection.name}.{msg.member}" with unexpected signature "{msg.signature}"'
             )
             return
@@ -300,8 +302,10 @@ class BaseProxyObject:
             intr_interface = next(
                 i for i in self.introspection.interfaces if i.name == name
             )
-        except StopIteration:
-            raise InterfaceNotFoundError(f"interface not found on this object: {name}")
+        except StopIteration as ex:
+            raise InterfaceNotFoundError(
+                f"interface not found on this object: {name}"
+            ) from ex
 
         interface = self.ProxyInterface(
             self.bus_name, self.path, intr_interface, self.bus
@@ -316,11 +320,11 @@ class BaseProxyObject:
 
         def get_owner_notify(msg: Message, err: Exception | None) -> None:
             if err:
-                logging.error(f'getting name owner for "{name}" failed, {err}')
+                _LOGGER.error(f'getting name owner for "{name}" failed, {err}')
                 return
             if msg.message_type == MessageType.ERROR:
                 if msg.error_name != ErrorType.NAME_HAS_NO_OWNER.value:
-                    logging.error(
+                    _LOGGER.error(
                         f'getting name owner for "{name}" failed, {msg.body[0]}'
                     )
                 return
